==> aiocrawler-1.17.tar.gz: aiocrawler-1.17/README.md <==

 
 ! [ v e r s i o n ] ( h t t p s : / / i m g . s h i e l d s . i o / b a d g e / v e r s i o n - v 1 . 1 5 - g r e e n . s v g ) 
 
 ! [ s u p p o r t ] ( h t t p s : / / i m g . s h i e l d s . i o / b a d g e / p y t h o n - 3 . 6 % 2 0 % 7 C % 2 0 3 . 7 - b l u e . s v g ) 
 
 ! [ l i c e n s e ] ( h t t p s : / / i m g . s h i e l d s . i o / b a d g e / l i c e n s e - M I T - y e l l o w . s v g ) 
 
 
 
 # # # #   A i o c r a w l e r   i s   a n   a s y n c h r o n o u s ,   d i s t r i b u t e d   c r a w l e r   f r a m e w o r k ,   y o u   c a n   u s e   i t   l i k e   s c r a p y . 
 
 
 
 -   # # #   i n s t a l l 
 
 ` ` ` b a s h 
 
 p i p 3   i n s t a l l   a i o c r a w l e r 
 
 ` ` ` 
 
 A n o t h e r   i n s t a l l a t i o n   m e t h o d 
 
 ` ` ` b a s h 
 
 p y t h o n 3   s e t u p . p y   i n s t a l l 
 
 ` ` ` 
 
 
 
 -   # # #   s t a r t   p r o j e c t 
 
 ` ` ` b a s h 
 
 a i o c r a w l e r   s t a r t p r o j e c t   d e m o 
 
 ` ` ` 
 
 * * T h i s   w i l l   c r e a t e   a   d e m o   d i r e c t o r y   w i t h   t h e   f o l l o w i n g   c o n t e n t s : * * 
 
 ` ` ` 
 
 + - -   d e m o / 
 
 |         + - -   i t e m s . p y 
 
 |         + - -   m i d d l e w a r e s . p y 
 
 |         + - -   r u n . p y 
 
 |         + - -   s e t t i n g s . p y 
 
 |         + - -   s p i d e r s . p y 
 
 ` ` ` 
 
 * * T h i s   i s   t h e   c o d e   f o r   y o u r   f i r s t   S p i d e r * * 
 
 ` ` ` p y t h o n 
 
 #   c o d i n g :   u t f - 8 
 
 f r o m   a i o c r a w l e r   i m p o r t   B a s e S e t t i n g s ,   S p i d e r ,   R e q u e s t 
 
 
 
 
 
 c l a s s   D e m o S p i d e r ( S p i d e r ) : 
 
         n a m e   =   " d e m o " 
 
 
 
         d e f   _ _ i n i t _ _ ( s e l f ,   s e t t i n g s :   B a s e S e t t i n g s ) : 
 
                 S p i d e r . _ _ i n i t _ _ ( s e l f ,   s e t t i n g s ) 
 
 
 
         d e f   m a k e _ r e q u e s t ( s e l f ,   w o r d ) : 
 
                 r e t u r n   R e q u e s t ( w o r d ,   c a l l b a c k = s e l f . p a r s e ) 
 
 
 
         d e f   p a r s e ( s e l f ,   r e s p o n s e ) : 
 
                 p a s s 
 
 ` ` ` 
 
 * * C o n f i g u r e   y o u r   s e t t i n g s . p y * * 
 
 ` ` ` p y t h o n 
 
 #   c o d i n g :   u t f - 8 
 
 f r o m   a i o c r a w l e r   i m p o r t   B a s e S e t t i n g s 
 
 f r o m   d e m o . m i d d l e w a r e s   i m p o r t   D e m o M i d d l e w a r e 
 
 
 
 
 
 c l a s s   D e m o S e t t i n g s ( B a s e S e t t i n g s ) : 
 
         P R O J E C T _ N A M E   =   ' d e m o ' 
 
 
 
         " " " 
 
         I f   y o u   u s e   t h e   r e d i s   s e r v e r   a s   t h e   s c h e d u l e r ,   t h e   R E D I S _ U R L   m u s t   b e   c o n f i g u r e d . 
 
         " " " 
 
         R E D I S _ U R L   =   ' r e d i s : / / u s e r : p a s s w o r d @ r e d i s _ a d d r e s s : p o r t ' 
 
         R E D I S _ P R O J E C T _ N A M E   =   ' d e m o ' 
 
 
 
         C O N C U R R E N T _ R E Q U E S T S   =   3 2 
 
         C O N C U R R E N T _ W O R D S   =   3 2 
 
         D E F A U L T _ T I M E O U T   =   2 0 
 
         D E F A U L T _ H E A D E R S   =   { 
 
                 ' A c c e p t ' :   ' t e x t / h t m l , a p p l i c a t i o n / x h t m l + x m l , a p p l i c a t i o n / x m l ; q = 0 . 9 , * / * ; q = 0 . 8 ' , 
 
                 ' A c c e p t - L a n g u a g e ' :   ' z h - C N ' , 
 
         } 
 
 
 
         D O W N L O A D _ D A L E Y   =   0 
 
         P R O C E S S _ D A L E Y   =   0 . 0 1 
 
         D O W N L O A D E R _ M I D D L E W A R E S   =   [ 
 
                 ( D e m o M i d d l e w a r e ,   3 0 0 ) , 
 
 
 
         ] 
 
 ` ` ` 
 
 
 
 # # #   r u n   t h e   p r o j e c t 
 
 ` ` ` b a s h 
 
 a i o c r a w l e r   r u n   d e m o 
 
 ` ` ` 
 
 

==> aiocrawler-1.18.tar.gz: aiocrawler-1.18/README.md <==

 
 ! [ v e r s i o n ] ( h t t p s : / / i m g . s h i e l d s . i o / b a d g e / v e r s i o n - v 1 . 1 5 - g r e e n . s v g ) 
 
 ! [ s u p p o r t ] ( h t t p s : / / i m g . s h i e l d s . i o / b a d g e / p y t h o n - 3 . 6 % 2 0 % 7 C % 2 0 3 . 7 - b l u e . s v g ) 
 
 ! [ l i c e n s e ] ( h t t p s : / / i m g . s h i e l d s . i o / b a d g e / l i c e n s e - M I T - y e l l o w . s v g ) 
 
 
 
 # # # #   A i o c r a w l e r   i s   a n   a s y n c h r o n o u s ,   d i s t r i b u t e d   c r a w l e r   f r a m e w o r k ,   y o u   c a n   u s e   i t   l i k e   s c r a p y . 
 
 
 
 -   # # #   I n s t a l l a t i o n 
 
 ` ` ` b a s h 
 
 p i p 3   i n s t a l l   a i o c r a w l e r 
 
 ` ` ` 
 
 A n o t h e r   i n s t a l l a t i o n 
 
 ` ` ` b a s h 
 
 p y t h o n 3   s e t u p . p y   i n s t a l l 
 
 ` ` ` 
 
 
 
 -   # # #   s t a r t   p r o j e c t 
 
 ` ` ` b a s h 
 
 a i o c r a w l e r   s t a r t p r o j e c t   d e m o 
 
 ` ` ` 
 
 * * T h i s   w i l l   c r e a t e   a   d e m o   d i r e c t o r y   w i t h   t h e   f o l l o w i n g   c o n t e n t s * * 
 
 ` ` ` 
 
 + - -   d e m o / 
 
 |         + - -   i t e m s . p y 
 
 |         + - -   m i d d l e w a r e s . p y 
 
 |         + - -   r u n . p y 
 
 |         + - -   s e t t i n g s . p y 
 
 |         + - -   s p i d e r s . p y 
 
 ` ` ` 
 
 * * T h i s   i s   t h e   c o d e   f o r   y o u r   f i r s t   S p i d e r * * 
 
 ` ` ` p y t h o n 
 
 #   c o d i n g :   u t f - 8 
 
 f r o m   a i o c r a w l e r   i m p o r t   B a s e S e t t i n g s ,   S p i d e r ,   R e q u e s t 
 
 
 
 
 
 c l a s s   D e m o S p i d e r ( S p i d e r ) : 
 
         n a m e   =   " d e m o " 
 
 
 
         d e f   _ _ i n i t _ _ ( s e l f ,   s e t t i n g s :   B a s e S e t t i n g s ) : 
 
                 S p i d e r . _ _ i n i t _ _ ( s e l f ,   s e t t i n g s ) 
 
 
 
         d e f   m a k e _ r e q u e s t ( s e l f ,   w o r d ) : 
 
                 r e t u r n   R e q u e s t ( w o r d ,   c a l l b a c k = s e l f . p a r s e ) 
 
 
 
         d e f   p a r s e ( s e l f ,   r e s p o n s e ) : 
 
                 p a s s 
 
 ` ` ` 
 
 * * C o n f i g u r e   y o u r   s e t t i n g s . p y * * 
 
 ` ` ` p y t h o n 
 
 #   c o d i n g :   u t f - 8 
 
 f r o m   a i o c r a w l e r   i m p o r t   B a s e S e t t i n g s 
 
 f r o m   d e m o . m i d d l e w a r e s   i m p o r t   D e m o M i d d l e w a r e 
 
 
 
 
 
 c l a s s   D e m o S e t t i n g s ( B a s e S e t t i n g s ) : 
 
         P R O J E C T _ N A M E   =   ' d e m o ' 
 
 
 
         " " " 
 
         I f   y o u   u s e   t h e   r e d i s   s e r v e r   a s   t h e   s c h e d u l e r ,   t h e   R E D I S _ U R L   m u s t   b e   c o n f i g u r e d . 
 
         " " " 
 
         R E D I S _ U R L   =   ' r e d i s : / / u s e r : p a s s w o r d @ r e d i s _ a d d r e s s : p o r t ' 
 
         R E D I S _ P R O J E C T _ N A M E   =   ' d e m o ' 
 
 
 
         C O N C U R R E N T _ R E Q U E S T S   =   3 2 
 
         C O N C U R R E N T _ W O R D S   =   3 2 
 
         D E F A U L T _ T I M E O U T   =   2 0 
 
         D E F A U L T _ H E A D E R S   =   { 
 
                 ' A c c e p t ' :   ' t e x t / h t m l , a p p l i c a t i o n / x h t m l + x m l , a p p l i c a t i o n / x m l ; q = 0 . 9 , * / * ; q = 0 . 8 ' , 
 
                 ' A c c e p t - L a n g u a g e ' :   ' z h - C N ' , 
 
         } 
 
 
 
         D O W N L O A D _ D A L E Y   =   0 
 
         P R O C E S S _ D A L E Y   =   0 . 0 1 
 
         D O W N L O A D E R _ M I D D L E W A R E S   =   [ 
 
                 ( D e m o M i d d l e w a r e ,   3 0 0 ) , 
 
 
 
         ] 
 
 ` ` ` 
 
 
 
 # # #   r u n   t h e   p r o j e c t 
 
 ` ` ` b a s h 
 
 a i o c r a w l e r   r u n   d e m o 
 
 ` ` ` 
 
 
